@@ -371,6 +371,10 @@ int main(int argc, char *argv[]) {
 		filepath(output_filepath, output_filename);
 	} else {
 		output_filename = argv[optind];
+		if (strlen(output_filename) >= PATH_MAX) {
+			fprintf(stderr, "'%s': filepath too long\n", output_filename);
+			return EXIT_FAILURE;
+		}
 		strcpy(output_filepath, output_filename);
 	}
 
@@ -460,7 +464,7 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (n_pending == 0) {
-		fprintf(stderr, "screenshot region is empty\n");
+		fprintf(stderr, "supplied geometry did not intersect with any outputs\n");
 		return EXIT_FAILURE;
 	}
 
@@ -483,7 +487,7 @@ int main(int argc, char *argv[]) {
 		return EXIT_FAILURE;
 	}
 
-	cairo_status_t status;
+	cairo_status_t status = CAIRO_STATUS_INVALID_STATUS;
 	if (strcmp(output_filename, "-") == 0) {
 		switch (output_filetype) {
 		case GRIM_FILETYPE_PPM:
